==> haskell-doctest-parallel-0.3.1-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-parallel
version:              0.3.1
visibility:           public
id:                   doctest-parallel-0.3.1-FoR1peWcdjoFZiS29tofqE
key:                  doctest-parallel-0.3.1-FoR1peWcdjoFZiS29tofqE
license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  936be74e7f6df42c16e0ab320018d38e
exposed:              True
exposed-modules:
    Test.DocTest Test.DocTest.Helpers Test.DocTest.Internal.Extract
    Test.DocTest.Internal.GhcUtil Test.DocTest.Internal.GhciWrapper
    Test.DocTest.Internal.Interpreter Test.DocTest.Internal.Location
    Test.DocTest.Internal.Logging Test.DocTest.Internal.Nix
    Test.DocTest.Internal.Options Test.DocTest.Internal.Parse
    Test.DocTest.Internal.Property Test.DocTest.Internal.Runner
    Test.DocTest.Internal.Runner.Example Test.DocTest.Internal.Util

hidden-modules:
    Control.Monad.Extra Data.List.Extra Paths_doctest_parallel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:         HSdoctest-parallel-0.3.1-FoR1peWcdjoFZiS29tofqE
depends:
    Cabal-3.8.1.0 Glob-0.10.2-9BO3Wh7Cn2N9awvk6Veumo base-4.17.2.1
    base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 ghc-9.4.8
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj process-1.6.18.0
    random-1.2.1.3-1kyQGGmKWocERAlRbbTx7C
    syb-0.7.3-DvMMPSfjQylGDaZxljQ4qT transformers-0.5.6.2
    unordered-containers-0.2.20-Eo1ocpXri5ABLOF81VToPu

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-doctest-parallel-z-spectests-modules
version:              0.3.1
package-name:         doctest-parallel
lib-name:             spectests-modules
id:
    doctest-parallel-0.3.1-6KXvjWpLoddIL2UuShlz0M-spectests-modules

key:
    doctest-parallel-0.3.1-6KXvjWpLoddIL2UuShlz0M-spectests-modules

license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  a1bf0e6b017d533637355ce9142adbc7
exposed-modules:
    BugfixImportHierarchical.ModuleA BugfixImportHierarchical.ModuleB
    BugfixMultipleModules.ModuleA BugfixMultipleModules.ModuleB
    BugfixOutputToStdErr.Fib Color.Foo DosLineEndings.Fib Failing.Foo
    FailingMultiple.Foo GhcArg.Fib It.Foo It.Setup LocalStderrBinding.A
    ModuleIsolation.TestA ModuleIsolation.TestB ModuleOptions.Foo
    Multiline.Multiline NonExposedModule.Exposed PropertyBool.Foo
    PropertyBoolWithTypeSignature.Foo PropertyFailing.Foo
    PropertyImplicitlyQuantified.Foo PropertyQuantified.Foo
    PropertySetup.Foo Setup.Foo SetupSkipOnFailure.Foo
    SystemIoImported.A TemplateHaskell.Foo TestBlankline.Fib
    TestCombinedExample.Fib TestCommentLocation.Foo
    TestDocumentationForArguments.Fib TestFailOnMultiline.Fib
    TestImport.ModuleA TestImport.ModuleB TestPutStr.Fib TestSimple.Fib
    TrailingWhitespace.Foo WithCInclude.Bar WithCbits.Bar

hidden-modules:       NonExposedModule.NoImplicitImport
import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:
    HSdoctest-parallel-0.3.1-6KXvjWpLoddIL2UuShlz0M-spectests-modules

depends:
    base-4.17.2.1 doctest-parallel-0.3.1-FoR1peWcdjoFZiS29tofqE
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-parallel-0.3.1-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-parallel
version:              0.3.1
visibility:           public
id:                   doctest-parallel-0.3.1-8rTeJALrNgr3GrKg5n4tMz
key:                  doctest-parallel-0.3.1-8rTeJALrNgr3GrKg5n4tMz
license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  363485cb148a28f01b29fedf797991ba
exposed:              True
exposed-modules:
    Test.DocTest Test.DocTest.Helpers Test.DocTest.Internal.Extract
    Test.DocTest.Internal.GhcUtil Test.DocTest.Internal.GhciWrapper
    Test.DocTest.Internal.Interpreter Test.DocTest.Internal.Location
    Test.DocTest.Internal.Logging Test.DocTest.Internal.Nix
    Test.DocTest.Internal.Options Test.DocTest.Internal.Parse
    Test.DocTest.Internal.Property Test.DocTest.Internal.Runner
    Test.DocTest.Internal.Runner.Example Test.DocTest.Internal.Util

hidden-modules:
    Control.Monad.Extra Data.List.Extra Paths_doctest_parallel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:         HSdoctest-parallel-0.3.1-8rTeJALrNgr3GrKg5n4tMz
depends:
    Cabal-3.8.1.0 Glob-0.10.2-A42QfjLoM1fDZmjwJwgg1 base-4.17.2.1
    base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 ghc-9.4.8
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj process-1.6.18.0
    random-1.2.1.3-DyhQJBMZMiBKToaxsRw6jM
    syb-0.7.3-82kecYkSnotJhXSs3T6xq0 transformers-0.5.6.2
    unordered-containers-0.2.20-psp1ib8v1R5J9F619BTWH

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-doctest-parallel-z-spectests-modules
version:              0.3.1
package-name:         doctest-parallel
lib-name:             spectests-modules
id:
    doctest-parallel-0.3.1-EfnpQmT2TAh5dWaCjPIKOa-spectests-modules

key:
    doctest-parallel-0.3.1-EfnpQmT2TAh5dWaCjPIKOa-spectests-modules

license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  32b644b8c95c95ac09e45083d1dd6864
exposed-modules:
    BugfixImportHierarchical.ModuleA BugfixImportHierarchical.ModuleB
    BugfixMultipleModules.ModuleA BugfixMultipleModules.ModuleB
    BugfixOutputToStdErr.Fib Color.Foo DosLineEndings.Fib Failing.Foo
    FailingMultiple.Foo GhcArg.Fib It.Foo It.Setup LocalStderrBinding.A
    ModuleIsolation.TestA ModuleIsolation.TestB ModuleOptions.Foo
    Multiline.Multiline NonExposedModule.Exposed PropertyBool.Foo
    PropertyBoolWithTypeSignature.Foo PropertyFailing.Foo
    PropertyImplicitlyQuantified.Foo PropertyQuantified.Foo
    PropertySetup.Foo Setup.Foo SetupSkipOnFailure.Foo
    SystemIoImported.A TemplateHaskell.Foo TestBlankline.Fib
    TestCombinedExample.Fib TestCommentLocation.Foo
    TestDocumentationForArguments.Fib TestFailOnMultiline.Fib
    TestImport.ModuleA TestImport.ModuleB TestPutStr.Fib TestSimple.Fib
    TrailingWhitespace.Foo WithCInclude.Bar WithCbits.Bar

hidden-modules:       NonExposedModule.NoImplicitImport
import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:
    HSdoctest-parallel-0.3.1-EfnpQmT2TAh5dWaCjPIKOa-spectests-modules

depends:
    base-4.17.2.1 doctest-parallel-0.3.1-8rTeJALrNgr3GrKg5n4tMz
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
